@@ -92,7 +92,7 @@ use Sys::Virt::DomainSnapshot;
 use Sys::Virt::DomainCheckpoint;
 use Sys::Virt::Stream;
 
-our $VERSION = '11.0.0';
+our $VERSION = '11.1.0';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -2017,7 +2017,7 @@ are the free count for that size.
 
 =item $con->node_alloc_pages(\@pages, $start, $end, $flags=0)
 
-Allocate further huge pages for the reserved dev. The <\@pages>
+Allocate further huge pages for the reserved dev. The C<\@pages>
 parameter is an array reference with one entry per page size to
 allocate for. Each entry is a further array reference where the
 first element is the page size and the second element is the
